@@ -1,20 +1,8 @@
-/***************************************************************************
- *   Copyright 2008-2010 Stefan Majewsky <majewsky@gmx.net>
- *
- *   This program is free software; you can redistribute it and/or
- *   modify it under the terms of the GNU General Public
- *   License as published by the Free Software Foundation; either
- *   version 2 of the License, or (at your option) any later version.
- *
- *   This program is distributed in the hope that it will be useful,
- *   but WITHOUT ANY WARRANTY; without even the implied warranty of
- *   MERCHANTABILITY or FITNESS FOR A PARTICULAR PURPOSE.  See the
- *   GNU General Public License for more details.
- *
- *   You should have received a copy of the GNU General Public License
- *   along with this program; if not, write to the Free Software
- *   Foundation, Inc., 51 Franklin Street, Fifth Floor, Boston, MA 02110-1301, USA.
- ***************************************************************************/
+/*
+    SPDX-FileCopyrightText: 2008-2010 Stefan Majewsky <majewsky@gmx.net>
+
+    SPDX-License-Identifier: GPL-2.0-or-later
+*/
 
 #include "diamond.h"
 
@@ -69,12 +57,12 @@ void Diamond::mouseMoveEvent(QGraphicsSceneMouseEvent *event)
         static const qreal draggingFuzziness = 2.0 / 3.0;
         if (qAbs(dx) > qAbs(dy)) {
             if (qAbs(dx) >= diamondSize.width() * draggingFuzziness) {
-                emit dragged(QPoint(dx < 0 ? -1 : 1, 0));
+                Q_EMIT dragged(QPoint(dx < 0 ? -1 : 1, 0));
                 m_mouseDown = false; //mouse action has been handled
             }
         } else {
             if (qAbs(dy) >= diamondSize.height() * draggingFuzziness) {
-                emit dragged(QPoint(0, dy < 0 ? -1 : 1));
+                Q_EMIT dragged(QPoint(0, dy < 0 ? -1 : 1));
                 m_mouseDown = false;
             }
         }
@@ -84,7 +72,7 @@ void Diamond::mouseMoveEvent(QGraphicsSceneMouseEvent *event)
 void Diamond::mouseReleaseEvent(QGraphicsSceneMouseEvent *event)
 {
     if (m_mouseDown && boundingRect().contains(event->pos())) {
-        emit clicked();
+        Q_EMIT clicked();
         m_mouseDown = false;
     }
 }
