@@ -1,20 +1,8 @@
-/***************************************************************************
- *   Copyright 2008-2010 Stefan Majewsky <majewsky@gmx.net>
- *
- *   This program is free software; you can redistribute it and/or
- *   modify it under the terms of the GNU General Public
- *   License as published by the Free Software Foundation; either
- *   version 2 of the License, or (at your option) any later version.
- *
- *   This program is distributed in the hope that it will be useful,
- *   but WITHOUT ANY WARRANTY; without even the implied warranty of
- *   MERCHANTABILITY or FITNESS FOR A PARTICULAR PURPOSE.  See the
- *   GNU General Public License for more details.
- *
- *   You should have received a copy of the GNU General Public License
- *   along with this program; if not, write to the Free Software
- *   Foundation, Inc., 51 Franklin Street, Fifth Floor, Boston, MA 02110-1301, USA.
- ***************************************************************************/
+/*
+    SPDX-FileCopyrightText: 2008-2010 Stefan Majewsky <majewsky@gmx.net>
+
+    SPDX-License-Identifier: GPL-2.0-or-later
+*/
 
 #include "mainwindow.h"
 #include "game.h"
@@ -81,11 +69,11 @@ MainWindow::MainWindow(QWidget *parent)
     m_newAct->addAction(m_newUntimedAct);
     connect(m_newUntimedAct, &QAction::triggered, this, &MainWindow::startGameDispatcher);
     //init GUI - the other actions
-    KStandardGameAction::highscores(this, SLOT(showHighscores()), actionCollection());
-    m_pauseAct = KStandardGameAction::pause(this, SLOT(pausedAction(bool)), actionCollection());
-    KStandardGameAction::quit(this, SLOT(close()), actionCollection());
+    KStandardGameAction::highscores(this, &MainWindow::showHighscores, actionCollection());
+    m_pauseAct = KStandardGameAction::pause(this, &MainWindow::pausedAction, actionCollection());
+    KStandardGameAction::quit(this, &QWidget::close, actionCollection());
     m_hintAct = KStandardGameAction::hint(nullptr, nullptr, actionCollection());
-    KStandardAction::preferences(&m_selector, SLOT(showAsDialog()), actionCollection());
+    KStandardAction::preferences(this, &MainWindow::showPreferences, actionCollection());
     KStandardAction::configureNotifications(this, &MainWindow::configureNotifications, actionCollection());
     //difficulty
     KgDifficultyGUI::init(this);
@@ -181,6 +169,12 @@ void MainWindow::showHighscores()
     delete dialog;
 }
 
+void MainWindow::showPreferences()
+{
+    m_selector.showAsDialog();
+}
+
+
 void MainWindow::pausedAction(bool paused)
 {
     m_gameState->setState(paused ? KDiamond::Paused : KDiamond::Playing);
